Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mono/libgit2sharp.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'LibGit2Sharp/MergeConflictException.cs')
-rw-r--r--LibGit2Sharp/MergeConflictException.cs53
1 files changed, 8 insertions, 45 deletions
diff --git a/LibGit2Sharp/MergeConflictException.cs b/LibGit2Sharp/MergeConflictException.cs
index 69ce3d6b..edcd5ebb 100644
--- a/LibGit2Sharp/MergeConflictException.cs
+++ b/LibGit2Sharp/MergeConflictException.cs
@@ -1,55 +1,18 @@
using System;
-using System.Runtime.Serialization;
-using LibGit2Sharp.Core;
+using System.Collections.Generic;
+using System.Linq;
+using System.Text;
namespace LibGit2Sharp
{
/// <summary>
/// The exception that is thrown when a merge cannot be performed because
/// of a conflicting change.
/// </summary>
[Serializable]
- public class MergeConflictException : LibGit2SharpException
+ [Obsolete("This type will be removed in the next release. Please use CheckoutConflictException instead.")]
+ public class MergeConflictException : CheckoutConflictException
{
- /// <summary>
- /// Initializes a new instance of the <see cref="LibGit2Sharp.MergeConflictException"/> class.
- /// </summary>
- public MergeConflictException()
- {
- }
-
- /// <summary>
- /// Initializes a new instance of the <see cref="LibGit2Sharp.MergeConflictException"/> class with a specified error message.
- /// </summary>
- /// <param name="message">A message that describes the error.</param>
- public MergeConflictException(string message)
- : base(message)
- {
- }
-
- /// <summary>
- /// Initializes a new instance of the <see cref="LibGit2Sharp.MergeConflictException"/> class with a specified error message and a reference to the inner exception that is the cause of this exception.
- /// </summary>
- /// <param name="message">The error message that explains the reason for the exception.</param>
- /// <param name="innerException">The exception that is the cause of the current exception. If the <paramref name="innerException"/> parameter is not a null reference, the current exception is raised in a catch block that handles the inner exception.</param>
- public MergeConflictException(string message, Exception innerException)
- : base(message, innerException)
- {
- }
-
- /// <summary>
- /// Initializes a new instance of the <see cref="LibGit2Sharp.MergeConflictException"/> class with a serialized data.
- /// </summary>
- /// <param name="info">The <see cref="SerializationInfo"/> that holds the serialized object data about the exception being thrown.</param>
- /// <param name="context">The <see cref="StreamingContext"/> that contains contextual information about the source or destination.</param>
- protected MergeConflictException(SerializationInfo info, StreamingContext context)
- : base(info, context)
- {
- }
-
- internal MergeConflictException(string message, GitErrorCode code, GitErrorCategory category)
- : base(message, code, category)
- {
- }
}
}
@@ -1,55 +1,18 @@
{
/// <summary>
- /// The exception that is thrown when a merge cannot be performed because
- /// of a conflicting change.
+ /// The exception that is thrown when a checkout cannot be performed
+ /// because of a conflicting change staged in the index, or unstaged
+ /// in the working directory.
/// </summary>
[Serializable]